@@ -14,7 +14,6 @@
  * High Level Board Configuration Options
  */
 #define	CONFIG_CPU_PXA27X		1	/* Marvell PXA270 CPU */
-#define	CONFIG_SYS_TEXT_BASE		0x0
 /* Avoid overwriting factory configuration block */
 #define CONFIG_BOARD_SIZE_LIMIT		0x40000
 
@@ -27,7 +26,6 @@
  * Environment settings
  */
 #define	CONFIG_ENV_OVERWRITE
-#define CONFIG_ENV_VARS_UBOOT_CONFIG
 #define CONFIG_ENV_VARS_UBOOT_RUNTIME_CONFIG
 #define	CONFIG_SYS_MALLOC_LEN		(128 * 1024)
 #define	CONFIG_ARCH_CPU_INIT
@@ -78,15 +76,9 @@
 #define	CONFIG_NET_RETRY_COUNT		10
 
 #define	CONFIG_BOOTP_BOOTFILESIZE
-#define	CONFIG_BOOTP_BOOTPATH
-#define	CONFIG_BOOTP_GATEWAY
-#define	CONFIG_BOOTP_HOSTNAME
 #endif
 
-#undef	CONFIG_SYS_LONGHELP		/* Saves 10 KB */
 #define	CONFIG_SYS_DEVICE_NULLDEV	1
-#undef	CONFIG_CMDLINE_EDITING		/* Saves 2.5 KB */
-#undef	CONFIG_AUTO_COMPLETE		/* Saves 2.5 KB */
 
 /*
  * Clock Configuration
