@@ -14,7 +14,6 @@
  /* High Level Configuration Options */
 
 #define CONFIG_SYS_FSL_CLK
-#define CONFIG_SYS_TEXT_BASE	0x97800000
 
 #include <asm/arch/imx-regs.h>
 
@@ -36,13 +35,6 @@
 
 #define CONFIG_MXC_UART
 #define CONFIG_MXC_UART_BASE	UART1_BASE
-#define CONFIG_MXC_GPIO
-
-/*
- * SPI Configs
- * */
-
-#define CONFIG_MXC_SPI
 
 /* PMIC Controller */
 #define CONFIG_POWER
@@ -169,16 +161,12 @@
 /*
  * Miscellaneous configurable options
  */
-#define CONFIG_SYS_LONGHELP		/* undef to save memory */
-#define CONFIG_AUTO_COMPLETE
 
 #define CONFIG_SYS_MEMTEST_START       0x90000000
 #define CONFIG_SYS_MEMTEST_END         0x90010000
 
 #define CONFIG_SYS_LOAD_ADDR		CONFIG_LOADADDR
 
-#define CONFIG_CMDLINE_EDITING
-
 /*-----------------------------------------------------------------------
  * Physical Memory Map
  */
