@@ -16,19 +16,31 @@ GNU_FPOST_ATTR
 
 #if CONFIG_POST & CONFIG_SYS_POST_FPU
 
-int fpu_post_test_math3 (void)
+static float rintf (float x)
 {
-	volatile long double dfrom = 1.1;
-	volatile long double m1;
-	volatile long double m2;
-	volatile unsigned long mant_long;
+	volatile float TWO23 = 8388608.0;
 
-	m1 = dfrom / 2.0;
-	m2 = m1 * 4294967296.0;
-	mant_long = ((unsigned long) m2) & 0xffffffff;
+	if (__builtin_fabs (x) < TWO23)
+	{
+		if (x > 0.0)
+		{
+			x += TWO23;
+			x -= TWO23;
+		}
+		else if (x < 0.0)
+		{
+			x = TWO23 - x;
+			x = -(x - TWO23);
+		}
+	}
 
-	if (mant_long != 0x8ccccccc) {
-		post_log ("Error in FPU math3 test\n");
+	return x;
+}
+
+int fpu_post_test_math2 (void)
+{
+	if (rintf (-1.5) != -2.0) {
+		post_log ("Error in FPU math2 test\n");
 		return -1;
 	}
 	return 0;
